==> nextcloud-app-spreed-1%3A9.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/bg.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Гост",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Бруней",
    "Bonaire, Sint Eustatius and Saba" : "отвъдморски територии на Нидерландия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Côte d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czechia" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "Western Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands (Malvinas)" : "Фолкландски острови (Малдиви)",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Honduras" : "Хондурас",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jersey" : "Джърси",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморски острови",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Montenegro" : "Черна гора",
    "Saint Martin (French part)" : "Сен Мартен",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Martinique" : "Мартиника",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russian Federation" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten (Dutch part)" : "Сен Мартен",
    "Syrian Arab Republic" : "Сирия",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Tanzania, United Republic of" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "United States of America" : "Съединени щати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Viet Nam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът е различен от ГГГГ-ММ-ДД",
    "Limit to groups" : "Ограничен достъп",
    "Everyone" : "Всички",
    "Save changes" : "Запиши промените",
    "Saving …" : "Записване …",
    "Saved!" : "Записано!",
    "None" : "Без",
    "User" : "Потребител",
    "Disabled" : "Изключено",
    "Users" : "Потребители",
    "Commands" : "Команди",
    "Beta" : "Бета",
    "Name" : "Име",
    "General settings" : "Общи настройки",
    "Language" : "Език",
    "Country" : "Държава",
    "Status" : "Състояние",
    "Created at" : "Създаден на",
    "Pending" : "Чакащо",
    "Error" : "Грешка",
    "Validate SSL certificate" : "Проверка на SSL сертификата",
    "Saved" : "Запазено",
    "STUN server URL" : "URL на STUN сървъра",
    "STUN servers" : "STUN сървъри",
    "TURN server URL" : "URL на TURN сървъра",
    "TURN server protocols" : "Протоколи на TURN сървър",
    "UDP and TCP" : "UDP и TCP",
    "UDP only" : "само UDP",
    "TCP only" : "само TCP",
    "Copy link" : "Копирай връзката",
    "Dismiss" : "Отхвърляне",
    "Mute audio" : "Спиране на звука",
    "Disable video" : "Изключване на видеото",
    "Enable video" : "Включи видео",
    "You" : "Ти",
    "Favorite" : "Любима",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Loading" : "Зареждане",
    "Groups" : "Групи",
    "Circles" : "Обкръжения",
    "Invalid path selected" : "Предоставен е невалиден път до файл.",
    "Password protect" : "Защита с парола",
    "Back" : "Назад",
    "Close" : "Затваряне",
    "Reply" : "Отговори",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "Send message" : "Изпрати съобщение",
    "guest" : "гост",
    "Remove participant" : "Премахване на участник",
    "Searching …" : "Търсене ...",
    "No results" : "Няма резултати",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Участници",
    "Chat" : "Съобщения",
    "Settings" : "Настройки",
    "Edit" : "Променяне",
    "Share link" : "Сподели връзка",
    "Password protection" : "Password protection",
    "Enter a password" : "Въведете парола",
    "Grid view" : "Решетъчен изглед",
    "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
    "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
    "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
    "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера",
    "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
    "Password" : "Парола",
    "TURN server" : "TURN сървър",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложениер",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Password required" : "Паролата е задължителна",
    "Cancel" : "Отказ",
    "Submit" : "Изпращане",
    "Guests" : "Гости",
    "Webinar" : "Уебинар",
    "Change password" : "Промени паролата",
    "Set password" : "Задайте парола",
    "Rename" : "Преименуване",
    "Link copied!" : "Връзката е копирана!",
    "Send" : "Изпрати",
    "Share" : "Споделяне",
    "Error while sharing" : "Грешка при споделяне",
    "Share screen" : "Споделяне на екран",
    "Favorited" : "Отбелязано в любими",
    "Contacts" : "Контакти"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/bg.js <==
OC.L10N.register(
    "spreed",
    {
    "Guest" : "Гост",
    "Messages" : "Съобщения",
    "Andorra" : "Андора",
    "United Arab Emirates" : "Обединени арабски емирства",
    "Afghanistan" : "Афганистан",
    "Antigua and Barbuda" : "Антигуа и Барбуда",
    "Anguilla" : "Ангила",
    "Albania" : "Албания",
    "Armenia" : "Армения",
    "Angola" : "Ангола",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аржентина",
    "American Samoa" : "Американска Самоа",
    "Austria" : "Австрия",
    "Australia" : "Австралия",
    "Aruba" : "Аруба",
    "Åland Islands" : "Оландски острови",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Босна и Херцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Белгия",
    "Burkina Faso" : "Буркина Фасо",
    "Bulgaria" : "България",
    "Bahrain" : "Бахрейн",
    "Burundi" : "Бурунди",
    "Benin" : "Бенин",
    "Saint Barthélemy" : "Сен Бартелеми",
    "Bermuda" : "Бермуда",
    "Brunei Darussalam" : "Бруней",
    "Bonaire, Sint Eustatius and Saba" : "отвъдморски територии на Нидерландия",
    "Brazil" : "Бразилия",
    "Bahamas" : "Бахамски острови",
    "Bhutan" : "Бутан",
    "Bouvet Island" : "остров Буве",
    "Botswana" : "Ботсуана",
    "Belarus" : "Беларус",
    "Belize" : "Белийз",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосови строви (Кийлинг)",
    "Central African Republic" : "Централноафриканска република",
    "Congo" : "Конго",
    "Switzerland" : "Швейцария",
    "Côte d'Ivoire" : "Кот д’Ивоар",
    "Cook Islands" : "Oстрови Кук",
    "Chile" : "Чили",
    "Cameroon" : "Камерун",
    "China" : "Китай",
    "Colombia" : "Колумбия",
    "Costa Rica" : "Коста Рика",
    "Cuba" : "Куба",
    "Cabo Verde" : "Кабо Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "остров Рождество",
    "Cyprus" : "Кипър",
    "Czechia" : "Чехия",
    "Germany" : "Германия",
    "Djibouti" : "Джибути",
    "Denmark" : "Дания",
    "Dominica" : "Доминика",
    "Dominican Republic" : "Доминиканска република",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естония",
    "Egypt" : "Египет",
    "Western Sahara" : "Западна Сахара",
    "Eritrea" : "Еритрея",
    "Spain" : "Испания",
    "Ethiopia" : "Етиопия",
    "Finland" : "Финландия",
    "Fiji" : "Фиджи",
    "Falkland Islands (Malvinas)" : "Фолкландски острови (Малдиви)",
    "Faroe Islands" : "Фарьорски острови",
    "France" : "Франция",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Обединено кралство",
    "Grenada" : "Гренада",
    "Georgia" : "Грузия",
    "French Guiana" : "Френска Гвиана",
    "Guernsey" : "Гърнзи",
    "Ghana" : "Гана",
    "Gibraltar" : "Гибралтар",
    "Greenland" : "Гренландия",
    "Gambia" : "Гамбия",
    "Guinea" : "Гвинея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваториална Гвинея",
    "Greece" : "Гърция",
    "South Georgia and the South Sandwich Islands" : "Южна Джорджия и Южни Сандвичеви острови",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвинея Бисау",
    "Guyana" : "Гвиaна",
    "Hong Kong" : "Хонконг",
    "Heard Island and McDonald Islands" : "Хърд и Макдоналд",
    "Honduras" : "Хондурас",
    "Croatia" : "Хърватия",
    "Haiti" : "Хаити",
    "Hungary" : "Унгария",
    "Indonesia" : "Индонезия",
    "Ireland" : "Ирландия",
    "Israel" : "Израел",
    "Isle of Man" : "Остров Ман",
    "India" : "Индия",
    "British Indian Ocean Territory" : "Британска индоокеанска територия",
    "Iraq" : "Ирак",
    "Iceland" : "Исландия",
    "Italy" : "Италия",
    "Jersey" : "Джърси",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йордания",
    "Japan" : "Япония",
    "Kenya" : "Кения",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кирибати",
    "Comoros" : "Коморски острови",
    "Saint Kitts and Nevis" : "Сейнт Китс и Невис",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманови острови",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаос",
    "Lebanon" : "Ливан",
    "Saint Lucia" : "Сейнт Лусия",
    "Liechtenstein" : "Лихтенщайн",
    "Sri Lanka" : "Шри Ланка",
    "Liberia" : "Либерия",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвия",
    "Libya" : "Либия",
    "Morocco" : "Мароко",
    "Monaco" : "Монако",
    "Montenegro" : "Черна гора",
    "Saint Martin (French part)" : "Сен Мартен",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршалови острови",
    "Mali" : "Мали",
    "Myanmar" : "Мианмар",
    "Mongolia" : "Монголия",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Северни Мариански острови",
    "Martinique" : "Мартиника",
    "Mauritania" : "Мавритания",
    "Montserrat" : "Монсерат",
    "Malta" : "Малта",
    "Mauritius" : "Мавриций",
    "Maldives" : "Малдиви",
    "Malawi" : "Малави",
    "Mexico" : "Мексико",
    "Malaysia" : "Малайзия",
    "Mozambique" : "Мозамбик",
    "Namibia" : "Намибия",
    "New Caledonia" : "Нова Каледония",
    "Niger" : "Нигер",
    "Norfolk Island" : "Oстров Норфолк",
    "Nigeria" : "Нигерия",
    "Nicaragua" : "Никарагуа",
    "Netherlands" : "Нидерландия",
    "Norway" : "Норвегия",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ниуе",
    "New Zealand" : "Нова Зеландия",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Френска Полинезия",
    "Papua New Guinea" : "Папуа Нова Гвинея",
    "Philippines" : "Филипини",
    "Pakistan" : "Пакистан",
    "Poland" : "Полша",
    "Saint Pierre and Miquelon" : "Сен Пиер и Микелон",
    "Pitcairn" : "Oстрови Питкерн",
    "Puerto Rico" : "Пуерто Рико",
    "Portugal" : "Португалия",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюнион",
    "Romania" : "Румъния",
    "Serbia" : "Сърбия",
    "Russian Federation" : "Русия",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудитска Арабия",
    "Solomon Islands" : "Соломонови острови",
    "Seychelles" : "Сейшелски острови",
    "Sudan" : "Судан",
    "Sweden" : "Швеция",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "Света Елена, Възнесение и Тристан да Куня",
    "Slovenia" : "Словения",
    "Svalbard and Jan Mayen" : "Свалбард и Ян Майен",
    "Slovakia" : "Словакия",
    "Sierra Leone" : "Сиера Леоне",
    "San Marino" : "Сан Марино",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалия",
    "Suriname" : "Суринам",
    "South Sudan" : "Южен Судан",
    "Sao Tome and Principe" : "Сао Томе и Принсипи",
    "El Salvador" : "Ел Салвадор",
    "Sint Maarten (Dutch part)" : "Сен Мартен",
    "Syrian Arab Republic" : "Сирия",
    "Turks and Caicos Islands" : "Търкс и Кайкос",
    "Chad" : "Чад",
    "French Southern Territories" : "Френски южни и антарктически територии",
    "Togo" : "Того",
    "Thailand" : "Тайланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Източен Тимор",
    "Turkmenistan" : "Туркменистан",
    "Tunisia" : "Тунис",
    "Tonga" : "Тонга",
    "Turkey" : "Турция",
    "Trinidad and Tobago" : "Тринидад и Тобаго",
    "Tuvalu" : "Тувалу",
    "Tanzania, United Republic of" : "Танзания",
    "Ukraine" : "Украйна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малки отдалечени острови на Съединените щати",
    "United States of America" : "Съединени щати",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Свети престол",
    "Saint Vincent and the Grenadines" : "Сейнт Винсънт и Гренадини",
    "Viet Nam" : "Виетнам",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолис и Футуна",
    "Samoa" : "Самоа",
    "Yemen" : "Йемен",
    "Mayotte" : "Майот",
    "South Africa" : "Южна Африка",
    "Zambia" : "Замбия",
    "Zimbabwe" : "Зимбабве",
    "Invalid date, date format must be YYYY-MM-DD" : "Невалидна дата, форматът е различен от ГГГГ-ММ-ДД",
    "Limit to groups" : "Ограничен достъп",
    "Everyone" : "Всички",
    "Save changes" : "Запиши промените",
    "Saving …" : "Записване …",
    "Saved!" : "Записано!",
    "None" : "Без",
    "User" : "Потребител",
    "Disabled" : "Изключено",
    "Users" : "Потребители",
    "Commands" : "Команди",
    "Beta" : "Бета",
    "Name" : "Име",
    "General settings" : "Общи настройки",
    "Language" : "Език",
    "Country" : "Държава",
    "Status" : "Състояние",
    "Created at" : "Създаден на",
    "Pending" : "Чакащо",
    "Error" : "Грешка",
    "Validate SSL certificate" : "Проверка на SSL сертификата",
    "Saved" : "Запазено",
    "STUN server URL" : "URL на STUN сървъра",
    "STUN servers" : "STUN сървъри",
    "TURN server URL" : "URL на TURN сървъра",
    "TURN server protocols" : "Протоколи на TURN сървър",
    "UDP and TCP" : "UDP и TCP",
    "UDP only" : "само UDP",
    "TCP only" : "само TCP",
    "Copy link" : "Копирай връзката",
    "Dismiss" : "Отхвърляне",
    "Mute audio" : "Спиране на звука",
    "Disable video" : "Изключване на видеото",
    "Enable video" : "Включи видео",
    "Back" : "Назад",
    "You" : "Ти",
    "Favorite" : "Любима",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "Loading" : "Зареждане",
    "Groups" : "Групи",
    "Circles" : "Обкръжения",
    "Settings" : "Настройки",
    "Password protect" : "Защита с парола",
    "Close" : "Затваряне",
    "Camera" : "Камера",
    "Reply" : "Отговори",
    "Remove" : "Премахни",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "Send message" : "Изпрати съобщение",
    "Invalid path selected" : "Предоставен е невалиден път до файл.",
    "Enabled" : "Включено",
    "Save" : "Запазване",
    "Password" : "Парола",
    "Login" : "Вписване",
    "Nickname" : "Псевдоним",
    "Client ID" : "Client ID",
    "guest" : "гост",
    "Remove participant" : "Премахване на участник",
    "Searching …" : "Търсене ...",
    "No results" : "Няма резултати",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Участници",
    "Chat" : "Съобщения",
    "Edit" : "Променяне",
    "Keyboard shortcuts" : "Бързи клавиши",
    "Search" : "Търсене",
    "Share link" : "Сподели връзка",
    "Password protection" : "Password protection",
    "Enter a password" : "Въведете парола",
    "Grid view" : "Решетъчен изглед",
    "Default" : "Стандартен",
    "Access to microphone & camera is only possible with HTTPS" : "Достъпът до микрофона и камерата е възможен само при HTTPS",
    "Access to microphone & camera was denied" : "Достъпът до микрофона и камерата е отказан",
    "Please use a different browser like Firefox or Chrome" : "Моля, използвайте друг браузър като Firefox или Chrome",
    "Error while accessing microphone & camera" : "Грешка при достъп до микрофон и камера",
    "The password is wrong. Try again." : "Паролата е грешна. Опитайте отново.",
    "TURN server" : "TURN сървър",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN сървърът се използва като прокси сървър за трафика, идващ от участници стоящи зад защитна стена.",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложениер",
    "Copy" : "Копиране",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не се поддържа!",
    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
    "Password required" : "Паролата е задължителна",
    "Cancel" : "Отказ",
    "Submit" : "Изпращане",
    "Guests" : "Гости",
    "Webinar" : "Уебинар",
    "Change password" : "Промени паролата",
    "Set password" : "Задайте парола",
    "Rename" : "Преименуване",
    "Link copied!" : "Връзката е копирана!",
    "Send" : "Изпрати",
    "Share" : "Споделяне",
    "Error while sharing" : "Грешка при споделяне",
    "Share screen" : "Споделяне на екран",
    "Favorited" : "Отбелязано в любими",
    "Contacts" : "Контакти"
},
"nplurals=2; plural=(n != 1);");
